@@ -1,6 +1,6 @@
-#!/usr/local/bin/python3.12
+#!/usr/local/bin/python3.13
 
-from pyUIClass.widg_addPolyOpt import Ui_Form
+from xasyqtui.widg_addPolyOpt import Ui_Form
 import PyQt5.QtWidgets as QtWidgets
 import PyQt5.QtGui as QtGui
 
